==> huaweicloudsdkiotedge-3.1.99-py2.py3-none-any.whl: huaweicloudsdkiotedge/v2/model/device_control_default_values_req_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeviceControlDefaultValuesReqDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'devices': 'list[DeviceDefaultValues]'
    }

    attribute_map = {
        'devices': 'devices'
    }

    def __init__(self, devices=None):
        """DeviceControlDefaultValuesReqDTO

        The model defined in huaweicloud sdk

        :param devices: 设备默认值数组
        :type devices: list[:class:`huaweicloudsdkiotedge.v2.DeviceDefaultValues`]
        """
        
        

        self._devices = None
        self.discriminator = None

        self.devices = devices

    @property
    def devices(self):
        """Gets the devices of this DeviceControlDefaultValuesReqDTO.

        设备默认值数组

        :return: The devices of this DeviceControlDefaultValuesReqDTO.
        :rtype: list[:class:`huaweicloudsdkiotedge.v2.DeviceDefaultValues`]
        """
        return self._devices

    @devices.setter
    def devices(self, devices):
        """Sets the devices of this DeviceControlDefaultValuesReqDTO.

        设备默认值数组

        :param devices: The devices of this DeviceControlDefaultValuesReqDTO.
        :type devices: list[:class:`huaweicloudsdkiotedge.v2.DeviceDefaultValues`]
        """
        self._devices = devices

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceControlDefaultValuesReqDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotedge-3.1.151-py2.py3-none-any.whl: huaweicloudsdkiotedge/v2/model/device_control_default_values_req_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeviceControlDefaultValuesReqDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'devices': 'list[DeviceDefaultValues]'
    }

    attribute_map = {
        'devices': 'devices'
    }

    def __init__(self, devices=None):
        r"""DeviceControlDefaultValuesReqDTO

        The model defined in huaweicloud sdk

        :param devices: 设备默认值数组
        :type devices: list[:class:`huaweicloudsdkiotedge.v2.DeviceDefaultValues`]
        """
        
        

        self._devices = None
        self.discriminator = None

        self.devices = devices

    @property
    def devices(self):
        r"""Gets the devices of this DeviceControlDefaultValuesReqDTO.

        设备默认值数组

        :return: The devices of this DeviceControlDefaultValuesReqDTO.
        :rtype: list[:class:`huaweicloudsdkiotedge.v2.DeviceDefaultValues`]
        """
        return self._devices

    @devices.setter
    def devices(self, devices):
        r"""Sets the devices of this DeviceControlDefaultValuesReqDTO.

        设备默认值数组

        :param devices: The devices of this DeviceControlDefaultValuesReqDTO.
        :type devices: list[:class:`huaweicloudsdkiotedge.v2.DeviceDefaultValues`]
        """
        self._devices = devices

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceControlDefaultValuesReqDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
